Index: Makefile
===================================================================
--- Makefile	(revision 310609)
+++ Makefile	(working copy)
@@ -1,25 +1,20 @@
-# New ports collection makefile for:	ogre3d
-# Date created:				03 Oct 2005
-# Whom:					Oliver Lehmann <oliver@FreeBSD.org>
-#
+# Created by: Oliver Lehmann <oliver@FreeBSD.org>
 # $FreeBSD$
-#
 
 PORTNAME=	ogre3d
-PORTVERSION=	1.7.4
-PORTREVISION=	1
+PORTVERSION=	1.8.1
 CATEGORIES=	graphics devel
-MASTER_SITES=	SF/ogre/ogre/${PORTVERSION:C/.[0-9]$//g}
+MASTER_SITES=	SF/ogre/ogre/${PORTVERSION:R}/${PORTVERSION}/
 DISTNAME=	ogre_src_v${PORTVERSION:S/./-/g}
 
 MAINTAINER=	oliver@FreeBSD.org
 COMMENT=	A scene-oriented, flexible 3D engine written in C++
 
-LIB_DEPENDS=	zzip.13:${PORTSDIR}/devel/zziplib \
-		freetype.9:${PORTSDIR}/print/freetype2 \
-		freeimage.3:${PORTSDIR}/graphics/freeimage
+LIB_DEPENDS=	zzip:${PORTSDIR}/devel/zziplib \
+		freetype:${PORTSDIR}/print/freetype2 \
+		freeimage:${PORTSDIR}/graphics/freeimage
 
-OPTIONS=	BOOST	"Use Boost to build threaded ogre"	off
+OPTIONS_DEFINE=	BOOST
 
 USE_LDCONFIG=	YES
 USE_BZIP2=	YES
@@ -28,9 +23,11 @@
 USE_XORG=	xaw
 MAKE_JOBS_SAFE=	yes
 
-.include <bsd.port.pre.mk>
+PLIST_SUB+=	PORTVERSION=${PORTVERSION}
 
-.if defined(WITH_BOOST)
+.include <bsd.port.options.mk>
+
+.if ${PORT_OPTIONS:MBOOST}
 BUILD_DEPENDS+=	${LOCALBASE}/include/boost/shared_ptr.hpp:${PORTSDIR}/devel/boost-libs
 RUND_DEPENDS+=	${LOCALBASE}/include/boost/shared_ptr.hpp:${PORTSDIR}/devel/boost-libs
 PLIST_SUB+=	BOOSTTRUE=""
@@ -64,11 +61,11 @@
 		${WRKSRC}/Tools/XMLConverter/src/tinyxmlparser.cpp \
 		${WRKSRC}/Tools/XMLConverter/include/OgreXMLPrerequisites.h
 post-install:
-.if !defined(NOPORTDOCS)
+.if ${PORT_OPTIONS:MDOCS}
 	@${MKDIR} ${DOCSDIR}
 .for docfile in README COPYING AUTHORS
 	@${INSTALL_DATA} ${WRKSRC}/${docfile} ${DOCSDIR}
 .endfor
 .endif
 
-.include <bsd.port.post.mk>
+.include <bsd.port.mk>
Index: distinfo
===================================================================
--- distinfo	(revision 310609)
+++ distinfo	(working copy)
@@ -1,2 +1,2 @@
-SHA256 (ogre_src_v1-7-4.tar.bz2) = afa475803d9e6980ddf3641dceaa53fcfbd348506ed67893c306766c166a4882
-SIZE (ogre_src_v1-7-4.tar.bz2) = 67391570
+SHA256 (ogre_src_v1-8-1.tar.bz2) = da908ac934265d25e378d336d648327afe569a758ef262029acd357d506f6aab
+SIZE (ogre_src_v1-8-1.tar.bz2) = 88619968
Index: files/patch-CMakeLists.txt
===================================================================
--- files/patch-CMakeLists.txt	(revision 310609)
+++ files/patch-CMakeLists.txt	(working copy)
@@ -1,14 +1,25 @@
---- CMakeLists.txt.orig	2011-08-21 00:25:46.000000000 +0200
-+++ CMakeLists.txt	2011-08-21 00:29:36.000000000 +0200
-@@ -291,6 +291,7 @@ cmake_dependent_option(OGRE_FULL_RPATH "
+--- CMakeLists.txt.orig	2012-09-02 07:27:14.000000000 +0200
++++ CMakeLists.txt	2012-11-07 14:29:44.000000000 +0100
+@@ -98,8 +98,8 @@
+     set(CMAKE_CXX_FLAGS "${CMAKE_CXX_FLAGS} -msse")
+   endif ()
+   # This is a set of sensible warnings that provide meaningful output
+-  set(OGRE_WARNING_FLAGS "-Wno-deprecated -Wall -Wctor-dtor-privacy -Winit-self -Wno-overloaded-virtual -Wcast-qual -Wwrite-strings -Wextra -Wno-unused-parameter -pedantic -Wshadow -Wno-missing-field-initializers -Wno-long-long")
+-  if (NOT APPLE)
++  set(OGRE_WARNING_FLAGS "-Wno-deprecated -Wall -Wctor-dtor-privacy -Winit-self -Wno-overloaded-virtual -Wcast-qual -Wwrite-strings -Wextra -Wno-unused-parameter -Wshadow -Wno-missing-field-initializers -Wno-long-long")
++  if (NOT APPLE AND NOT UNIX)
+       set(OGRE_WARNING_FLAGS "${OGRE_WARNING_FLAGS} -Wno-unused-but-set-parameter")
+   endif ()
+   set(CMAKE_CXX_FLAGS "${CMAKE_CXX_FLAGS} ${OGRE_WARNING_FLAGS}")
+@@ -322,6 +322,7 @@
  option(OGRE_PROFILING "Enable internal profiling support." FALSE)
  cmake_dependent_option(OGRE_CONFIG_STATIC_LINK_CRT "Statically link the MS CRT dlls (msvcrt)" FALSE "MSVC" FALSE)
  set(OGRE_LIB_DIRECTORY "lib${LIB_SUFFIX}" CACHE STRING "Install path for libraries, e.g. 'lib64' on some 64-bit Linux distros.")
 +set(OGRE_LIBDATA_DIRECTORY "libdata" CACHE STRING "Install path for data files.")
  
- # hide advanced options
- mark_as_advanced(
-@@ -314,6 +315,7 @@ mark_as_advanced(
+ # Unity build options
+ # A Unity build includes all sources files in just a few actual compilation units
+@@ -353,6 +354,7 @@
    OGRE_PROFILING
    OGRE_CONFIG_STATIC_LINK_CRT
    OGRE_LIB_DIRECTORY
Index: pkg-plist
===================================================================
--- pkg-plist	(revision 310609)
+++ pkg-plist	(working copy)
@@ -52,7 +52,10 @@
 include/OGRE/OgreDDSCodec.h
 include/OGRE/OgreDataStream.h
 include/OGRE/OgreDefaultHardwareBufferManager.h
+include/OGRE/OgreDeflate.h
+include/OGRE/OgreDepthBuffer.h
 include/OGRE/OgreDistanceLodStrategy.h
+include/OGRE/OgreDualQuaternion.h
 include/OGRE/OgreDynLib.h
 include/OGRE/OgreDynLibManager.h
 include/OGRE/OgreEdgeListBuilder.h
@@ -84,6 +87,13 @@
 include/OGRE/OgreHighLevelGpuProgramManager.h
 include/OGRE/OgreImage.h
 include/OGRE/OgreImageCodec.h
+include/OGRE/OgreInstanceBatch.h
+include/OGRE/OgreInstanceBatchHW.h
+include/OGRE/OgreInstanceBatchHW_VTF.h
+include/OGRE/OgreInstanceBatchShader.h
+include/OGRE/OgreInstanceBatchVTF.h
+include/OGRE/OgreInstanceManager.h
+include/OGRE/OgreInstancedEntity.h
 include/OGRE/OgreInstancedGeometry.h
 include/OGRE/OgreIteratorRange.h
 include/OGRE/OgreIteratorWrapper.h
@@ -210,6 +220,7 @@
 include/OGRE/OgreSkeletonInstance.h
 include/OGRE/OgreSkeletonManager.h
 include/OGRE/OgreSkeletonSerializer.h
+include/OGRE/OgreSmallVector.h
 include/OGRE/OgreSphere.h
 include/OGRE/OgreSpotShadowFadePng.h
 include/OGRE/OgreStableHeaders.h
@@ -246,6 +257,7 @@
 include/OGRE/OgreWorkQueue.h
 include/OGRE/OgreZip.h
 include/OGRE/Paging/OgreGrid2DPageStrategy.h
+include/OGRE/Paging/OgreGrid3DPageStrategy.h
 include/OGRE/Paging/OgrePage.h
 include/OGRE/Paging/OgrePageConnection.h
 include/OGRE/Paging/OgrePageContent.h
@@ -271,30 +283,17 @@
 include/OGRE/Plugins/BSPSceneManager/OgreQuake3Shader.h
 include/OGRE/Plugins/BSPSceneManager/OgreQuake3ShaderManager.h
 include/OGRE/Plugins/BSPSceneManager/OgreQuake3Types.h
-include/OGRE/Plugins/OctreeSceneManager/OgreHeightmapTerrainPageSource.h
 include/OGRE/Plugins/OctreeSceneManager/OgreOctree.h
 include/OGRE/Plugins/OctreeSceneManager/OgreOctreeCamera.h
 include/OGRE/Plugins/OctreeSceneManager/OgreOctreeNode.h
 include/OGRE/Plugins/OctreeSceneManager/OgreOctreePlugin.h
+include/OGRE/Plugins/OctreeSceneManager/OgreOctreePrerequisites.h
 include/OGRE/Plugins/OctreeSceneManager/OgreOctreeSceneManager.h
 include/OGRE/Plugins/OctreeSceneManager/OgreOctreeSceneQuery.h
-include/OGRE/Plugins/OctreeSceneManager/OgreTerrainPage.h
-include/OGRE/Plugins/OctreeSceneManager/OgreTerrainPageSource.h
-include/OGRE/Plugins/OctreeSceneManager/OgreTerrainPrerequisites.h
-include/OGRE/Plugins/OctreeSceneManager/OgreTerrainRenderable.h
-include/OGRE/Plugins/OctreeSceneManager/OgreTerrainSceneManager.h
-include/OGRE/Plugins/OctreeSceneManager/OgreTerrainVertexProgram.h
-include/OGRE/Plugins/OctreeZone/OgreHeightmapTerrainZonePageSource.h
 include/OGRE/Plugins/OctreeZone/OgreOctreeZone.h
 include/OGRE/Plugins/OctreeZone/OgreOctreeZoneOctree.h
 include/OGRE/Plugins/OctreeZone/OgreOctreeZonePlugin.h
 include/OGRE/Plugins/OctreeZone/OgreOctreeZonePrerequisites.h
-include/OGRE/Plugins/OctreeZone/OgreTerrainVertexProgram.h
-include/OGRE/Plugins/OctreeZone/OgreTerrainZone.h
-include/OGRE/Plugins/OctreeZone/OgreTerrainZonePage.h
-include/OGRE/Plugins/OctreeZone/OgreTerrainZonePageSource.h
-include/OGRE/Plugins/OctreeZone/OgreTerrainZonePrerequisites.h
-include/OGRE/Plugins/OctreeZone/OgreTerrainZoneRenderable.h
 include/OGRE/Plugins/PCZSceneManager/OgreAntiPortal.h
 include/OGRE/Plugins/PCZSceneManager/OgreCapsule.h
 include/OGRE/Plugins/PCZSceneManager/OgreDefaultZone.h
@@ -350,9 +349,15 @@
 include/OGRE/RTShaderSystem/OgreRTShaderSystem.h
 include/OGRE/RTShaderSystem/OgreShaderCGProgramProcessor.h
 include/OGRE/RTShaderSystem/OgreShaderCGProgramWriter.h
+include/OGRE/RTShaderSystem/OgreShaderExDualQuaternionSkinning.h
+include/OGRE/RTShaderSystem/OgreShaderExHardwareSkinning.h
+include/OGRE/RTShaderSystem/OgreShaderExHardwareSkinningTechnique.h
 include/OGRE/RTShaderSystem/OgreShaderExIntegratedPSSM3.h
+include/OGRE/RTShaderSystem/OgreShaderExLayeredBlending.h
+include/OGRE/RTShaderSystem/OgreShaderExLinearSkinning.h
 include/OGRE/RTShaderSystem/OgreShaderExNormalMapLighting.h
 include/OGRE/RTShaderSystem/OgreShaderExPerPixelLighting.h
+include/OGRE/RTShaderSystem/OgreShaderExTextureAtlasSampler.h
 include/OGRE/RTShaderSystem/OgreShaderFFPColour.h
 include/OGRE/RTShaderSystem/OgreShaderFFPFog.h
 include/OGRE/RTShaderSystem/OgreShaderFFPLighting.h
@@ -362,6 +367,8 @@
 include/OGRE/RTShaderSystem/OgreShaderFFPTransform.h
 include/OGRE/RTShaderSystem/OgreShaderFunction.h
 include/OGRE/RTShaderSystem/OgreShaderFunctionAtom.h
+include/OGRE/RTShaderSystem/OgreShaderGLSLESProgramProcessor.h
+include/OGRE/RTShaderSystem/OgreShaderGLSLESProgramWriter.h
 include/OGRE/RTShaderSystem/OgreShaderGLSLProgramProcessor.h
 include/OGRE/RTShaderSystem/OgreShaderGLSLProgramWriter.h
 include/OGRE/RTShaderSystem/OgreShaderGenerator.h
@@ -396,6 +403,7 @@
 include/OGRE/RenderSystems/GL/OgreGLATIFSInit.h
 include/OGRE/RenderSystems/GL/OgreGLContext.h
 include/OGRE/RenderSystems/GL/OgreGLDefaultHardwareBufferManager.h
+include/OGRE/RenderSystems/GL/OgreGLDepthBuffer.h
 include/OGRE/RenderSystems/GL/OgreGLFBOMultiRenderTarget.h
 include/OGRE/RenderSystems/GL/OgreGLFBORenderTexture.h
 include/OGRE/RenderSystems/GL/OgreGLFrameBufferObject.h
@@ -448,30 +456,38 @@
 include/OGRE/Threading/OgreThreadHeaders.h
 %%BOOSTTRUE%%include/OGRE/Threading/OgreThreadHeadersBoost.h
 include/OGRE/asm_math.h
+lib/OGRE/Plugin_BSPSceneManager.so.%%PORTVERSION%%
 lib/OGRE/Plugin_BSPSceneManager.so
+lib/OGRE/Plugin_OctreeSceneManager.so.%%PORTVERSION%%
 lib/OGRE/Plugin_OctreeSceneManager.so
+lib/OGRE/Plugin_OctreeZone.so.%%PORTVERSION%%
 lib/OGRE/Plugin_OctreeZone.so
+lib/OGRE/Plugin_PCZSceneManager.so.%%PORTVERSION%%
 lib/OGRE/Plugin_PCZSceneManager.so
+lib/OGRE/Plugin_ParticleFX.so.%%PORTVERSION%%
 lib/OGRE/Plugin_ParticleFX.so
+lib/OGRE/RenderSystem_GL.so.%%PORTVERSION%%
 lib/OGRE/RenderSystem_GL.so
 lib/OGRE/cmake/FindOGRE.cmake
 lib/OGRE/cmake/FindOIS.cmake
 lib/OGRE/cmake/FindPkgMacros.cmake
 lib/OGRE/cmake/MacroLogFeature.cmake
+lib/OGRE/cmake/OgreAddTargets.cmake
 lib/OGRE/cmake/OgreConfigTargets.cmake
 lib/OGRE/cmake/OgreFindFrameworks.cmake
 lib/OGRE/cmake/OgreGetVersion.cmake
+lib/OGRE/cmake/PrecompiledHeader.cmake
 lib/OGRE/cmake/PreprocessorUtils.cmake
 lib/libOgreMain.so
-lib/libOgreMain.so.1.7.4
+lib/libOgreMain.so.%%PORTVERSION%%
 lib/libOgrePaging.so
-lib/libOgrePaging.so.1.7.4
+lib/libOgrePaging.so.%%PORTVERSION%%
 %%BOOSTTRUE%%lib/libOgreProperty.so
-%%BOOSTTRUE%%lib/libOgreProperty.so.1.7.4
+%%BOOSTTRUE%%lib/libOgreProperty.so.%%PORTVERSION%%
 lib/libOgreRTShaderSystem.so
-lib/libOgreRTShaderSystem.so.1.7.4
+lib/libOgreRTShaderSystem.so.%%PORTVERSION%%
 lib/libOgreTerrain.so
-lib/libOgreTerrain.so.1.7.4
+lib/libOgreTerrain.so.%%PORTVERSION%%
 libdata/pkgconfig/OGRE-PCZ.pc
 libdata/pkgconfig/OGRE-Paging.pc
 %%BOOSTTRUE%%libdata/pkgconfig/OGRE-Property.pc
